from yta_constants.enum import YTAEnum as Enum


class ColorString(Enum):
    """
    The hexadecimal string that corresponds to the color.
    """
    
    WHITE = '#FFFFFF'
    BLACK = '#000000'
    RED = '#FF000000'
    GREEN = '#00FF00'
    BLUE = '#0000FF'
    # TODO: Add colors from Manim or other libraries